@@ -70,13 +70,13 @@ def gauss_model_2save(x_min, x_max, data, num_bin, *args):
     Parameters
     ----------
     x_min : float
-        The minimum value to consider in the fit
+        The minimum value to consider in the fit.
 
     x_max : float
-        The maximum value to consider in the fit
+        The maximum value to consider in the fit.
 
-    data : array-like, shape (n_samples,)
-        The data to be fit
+    data : list, len(n_samples)
+        The data to be fit.
 
     num_bin : int
         The number of bins to include in the histogram, which is
@@ -84,40 +84,40 @@ def gauss_model_2save(x_min, x_max, data, num_bin, *args):
 
     args : optional, string
         An optional argument that would give the color of the
-        histogram
+        histogram.
 
     Returns
     -------
     center_abs : float
-        The center of the Gaussian fit
+        The center of the Gaussian fit.
 
     center_err : float
-        The uncertainty in the center of the fit
+        The uncertainty in the center of the fit.
 
     chi_sq : float
-        The chi squared statistic of the fit
+        The chi squared statistic of the fit.
 
     red_chi_sq : float
-        The reduced chi squared statistic of the fit
+        The reduced chi squared statistic of the fit.
 
     sigma_abs : float
-        The standard deviation of the fit
+        The standard deviation of the fit.
 
     sigma_err : float
-        The uncertainty in the standard deviation of the fit
+        The uncertainty in the standard deviation of the fit.
 
     height_abs : float
-        The height of the Gaussian fit
+        The height of the Gaussian fit.
 
     height_err : float
-        The uncertainty in the height of the fit
+        The uncertainty in the height of the fit.
 
     fw_hm_abs : float
-        The full width at half max value for the curve
+        The full width at half max value for the curve.
 
     fw_hm_err : float
         The uncertainty in the full width at half max value for the
-        curve
+        curve.
     """
     new_blue = '#3F5D7D'
     if len(args) == 0:
@@ -164,16 +164,11 @@ def gauss_model_2save(x_min, x_max, data, num_bin, *args):
 
         if len(x_bins[0]) in [3, 4]:
             print(
-                "Number of bins == %i, too few for effective fit to"
+                "Number of bins == %i, too few for effective fit to "
                 "Gaussian curve.\nUse weighted average method instead.\n" % len(x_bins[0]))
 
-        weights = []
-        for j in range(len(x_bins[0])):
-            weight = x_bins[0][j] / sum(x_bins[0])
-            weights.append(weight)
-
-        x = sum(x_center * weights)
-        x_err = np.array(x_bins[1][1:] - x_bins[1][:-1])[0]
+        # noinspection PyTypeChecker
+        x, x_err = wt_avg_unc_number(data, x_max - x_min)
 
         center_abs = x
         center_err = x_err
@@ -369,7 +364,7 @@ class GaussianMixtureModel(GaussianMixtureBase):
                              "either 'Cartesian' or 'Polar', but"
                              "got %s instead." % self.coordinates)
 
-    def _GMM_fit(self, x, n_components):
+    def _gmm_fit(self, x, n_components):
         """The method that fits a Gaussian Mixture Model to the data given by x.
 
         Parameters
@@ -433,34 +428,20 @@ class GaussianMixtureModel(GaussianMixtureBase):
             # Calculate the radii and phases of cluster centers, with standard errors
             rs = np.sqrt(np.square(np.subtract(c1s, xC)) +
                          np.square(np.subtract(c2s, yC)))
-            rs_err = np.sqrt(np.add(np.add(np.multiply(np.square(np.divide(
-                np.subtract(c1s, xC), rs)), np.square(c1s_err)), np.multiply(
-                np.square(np.divide(np.subtract(c1s, xC), rs)), np.square(xC_unc))), np.add(
-                np.multiply(np.square(np.divide(np.subtract(c2s, yC), rs)),
-                            np.square(c2s_err)), np.multiply(
-                    np.square(np.divide(np.subtract(c2s, yC), rs)), np.square(yC_unc)))))
+            rs_err = (1 / rs) * np.sqrt((c1s_err * (c1s - xC)) ** 2 +
+                                        (xC_unc * (c1s - xC)) ** 2 +
+                                        (c2s_err * (c2s - yC)) ** 2 +
+                                        (yC_unc * (c2s - yC)) ** 2)
             ps = np.rad2deg(np.arctan(np.divide(np.subtract(c2s, yC), np.subtract(c1s, xC))))
             for i in range(len(c1s)):
                 if c1s[i] - xC < 0:
                     ps[i] += 180
                 if c1s[i] - xC > 0 > c2s[i] - yC:
                     ps[i] += 360
-            ps_err = np.rad2deg(np.sqrt(np.add(np.add(np.square(np.multiply(np.multiply(
-                np.divide(1, np.add(1, np.square(np.divide(np.subtract(c2s, yC),
-                                                           np.subtract(c1s, xC))))),
-                np.divide(np.subtract(yC, c2s), np.square(np.subtract(c1s, xC)))),
-                c1s_err)), np.square(np.multiply(np.multiply(np.divide(1, np.add(
-                    1, np.square(np.divide(np.subtract(c2s, yC), np.subtract(c1s, xC))))),
-                                                             np.divide(np.subtract(
-                                                                 yC, c2s), np.square(
-                                                                 np.subtract(c1s, xC)))), xC_unc))), np.add(
-                np.square(np.multiply(np.multiply(np.divide(1, np.add(1, np.square(
-                    np.divide(np.subtract(c2s, yC), np.subtract(c1s, xC))))),
-                                                  np.divide(1, np.subtract(c1s, xC))),
-                                      c2s_err)), np.square(np.multiply(np.multiply(
-                                        np.divide(1, np.add(1, np.square(np.divide(np.subtract(c2s, yC),
-                                                            np.subtract(c1s, xC))))),
-                                        np.divide(1, np.subtract(c1s, xC))), yC_unc))))))
+            ps_err = np.rad2deg((1 / rs ** 2) * np.sqrt((c2s_err * (c1s - xC)) ** 2 +
+                                                        (yC_unc * (c1s - xC)) ** 2 +
+                                                        (c1s_err * (c2s - yC)) ** 2 +
+                                                        (xC_unc * (c2s - yC)) ** 2))
 
             cluster_err = np.sqrt(np.add(np.square(c1s_err),
                                          np.square(c2s_err)))
@@ -493,16 +474,14 @@ class GaussianMixtureModel(GaussianMixtureBase):
             phases = np.deg2rad(c2s)
             phases_err = np.deg2rad(c2s_err)
 
-            xs = np.add(np.multiply(c1s, np.cos(phases)), xC)
-            xs_err = np.sqrt(np.add(np.add(np.square(np.multiply(np.cos(
-                phases), c1s_err)), np.square(np.multiply(
-                    np.multiply(c1s, np.sin(phases)), phases_err))),
-                xC_unc ** 2))
-            ys = np.add(np.multiply(c1s, np.sin(phases)), yC)
-            ys_err = np.sqrt(np.add(np.add(np.square(np.multiply(np.sin(
-                phases), c1s_err)), np.square(np.multiply(
-                    np.multiply(c1s, np.cos(phases)), phases_err))),
-                yC_unc ** 2))
+            xs = (c1s * np.cos(phases)) + xC
+            xs_err = np.sqrt((c1s_err * np.cos(phases)) ** 2 +
+                             (phases_err * c1s * np.sin(phases)) ** 2 +
+                             xC_unc ** 2)
+            ys = (c1s * np.sin(phases)) + yC
+            ys_err = np.sqrt((c1s_err * np.sin(phases)) ** 2 +
+                             (phases_err * c1s * np.cos(phases)) ** 2 +
+                             yC_unc ** 2)
             cluster_err = np.sqrt(np.add(np.square(xs_err),
                                          np.square(ys_err)))
 
@@ -669,10 +648,7 @@ class GaussianMixtureModel(GaussianMixtureBase):
 
                     c1_fit_array = np.array(c1_fit)
                     c2_fit_array = np.array(c2_fit)
-                    if np.isnan(c1_fit_array.astype(float)[1]) \
-                            or np.isnan(c2_fit_array.astype(float)[1]) \
-                            or 0.0001 >= c1_fit_array[1] or \
-                            0.0001 >= c2_fit_array[1]:
+                    if c1_fit[1] >= 5 or c2_fit[1] >= 5:
 
                         c1, c1_err = wt_avg_unc_number(c1_cut, width_c1)
                         c2, c2_err = wt_avg_unc_number(c2_cut, width_c2)
@@ -770,7 +746,7 @@ class GaussianMixtureModel(GaussianMixtureBase):
         ic_list = []
 
         if __name__ == 'GMMClusteringAlgorithms.classes._gaussian_mixture_model':
-            func = partial(self._GMM_fit, x)  # Initialize function to be processed
+            func = partial(self._gmm_fit, x)  # Initialize function to be processed
             results = Parallel(n_jobs=n_cores)(delayed(func)(i)  # Process results
                                                for i in inputs)
 
@@ -835,7 +811,7 @@ class GaussianMixtureModel(GaussianMixtureBase):
                    :, (2, 3)]
 
         if __name__ == 'GMMClusteringAlgorithms.classes._gaussian_mixture_model':
-            func = partial(self._GMM_fit, data)  # Initialize function to be processed
+            func = partial(self._gmm_fit, data)  # Initialize function to be processed
             results = Parallel(n_jobs=n_cores)(delayed(func)(i)  # Process function
                                                for i in inputs)
 
@@ -896,7 +872,7 @@ class GaussianMixtureModel(GaussianMixtureBase):
             data = data_frame_object.data_array_[
                    :, (2, 3)]
 
-        model = self._GMM_fit(data, self.n_components)
+        model = self._gmm_fit(data, self.n_components)
 
         # Assign attributes
         self.means_ = model.means_
